import React, { useEffect, useRef, useState } from 'react'

const LazyLoadImage = ({ src, alt, placeholderColor = '#e0e0e0', ...props }) => {

    const [isVisible, setIsVisible] = useState(false)
    const imgRef = useRef(null);

    useEffect(() => {
        const observer = new IntersectionObserver(
            (entries) => {
                entries.forEach(entry => {
                    if (entry.isIntersecting) {
                        setIsVisible(true);
                        observer.disconnect();
                    }
                })
            },
            {
                root: null,
                rootMargin: '0px',
                threshold: 0.1,
            }
        )

        const currentImgRef = imgRef.current;

        if (currentImgRef) {
            observer.observe(currentImgRef)
        }

        return () => {
            if (currentImgRef) {
                observer.unobserve(currentImgRef)
            }
        }

    }, [])

    return (
        <div
            style={{
                backgroundColor: !isVisible ? placeholderColor : 'transparent',
                transition: 'background-color 0.5s ease-in-out',
                width: props.width,
                height: props.height,
                display: 'flex',
                alignItems: 'center',
                justifyContent: 'center',
                overflow: 'hidden',
                borderRadius: '8px',
            }}
        >
            <img
                ref={imgRef}
                src={isVisible ? src : ''}
                alt={alt}
                {...props}
                style={{
                    opacity: isVisible ? 1 : 0,
                    transition: 'opacity 0.5s ease-in-out',
                    width: '100%',
                    height: '100%',
                    objectFit: 'cover',
                }}
            />
        </div>
    )
}

export default LazyLoadImage
